@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from vertica_python.vertica.messages.message import BackendMessage
 
@@ -7,4 +7,4 @@ class CloseComplete(BackendMessage):
     pass
 
 
-CloseComplete._message_id('3')
+CloseComplete._message_id(b'3')
