@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 import re
 
@@ -13,15 +13,15 @@ class CommandComplete(BackendMessage):
 
         data = unpack('{0}sx'.format(len(data) - 1), data)[0]
 
-        if re.match("INSERT", data) is not None:
-            splitstr = data.split(' ', 3)
+        if re.match(b"INSERT", data) is not None:
+            splitstr = data.split(b' ', 3)
             self.tag = splitstr[0]
             if len(splitstr) >= 2:
                 self.oid = int(splitstr[1])
             if len(splitstr) >= 3:
                 self.rows = int(splitstr[2])
-        elif re.match("(DELETE|UPDATE|MOVE|FETCH|COPY)", data) is not None:
-            splitstr = data.split(' ', 2)
+        elif re.match(b"(DELETE|UPDATE|MOVE|FETCH|COPY)", data) is not None:
+            splitstr = data.split(b' ', 2)
             self.tag = splitstr[0]
             if len(splitstr) >= 2:
                 self.rows = int(splitstr[1])
@@ -29,4 +29,4 @@ class CommandComplete(BackendMessage):
             self.tag = data
 
 
-CommandComplete._message_id('C')
+CommandComplete._message_id(b'C')
