@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from vertica_python.vertica.messages.message import BackendMessage
 
@@ -7,4 +7,4 @@ class EmptyQueryResponse(BackendMessage):
     pass
 
 
-EmptyQueryResponse._message_id('I')
+EmptyQueryResponse._message_id(b'I')
