@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from vertica_python.vertica.messages.message import BackendMessage
 from vertica_python.vertica.messages.backend_messages.notice_response import NoticeResponse
@@ -8,4 +8,4 @@ class ErrorResponse(NoticeResponse, BackendMessage):
     pass
 
 
-ErrorResponse._message_id('E')
+ErrorResponse._message_id(b'E')
