@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from struct import unpack, unpack_from
 
@@ -11,7 +11,7 @@ class ParameterDescription(BackendMessage):
     def __init__(self, data):
         parameter_count = unpack('!H', data)[0]
         parameter_type_ids = unpack_from("!{0}N".format(parameter_count), data, 2)
-        self.parameter_types = [Column.DATA_TYPES[dtid] for dtid in parameter_type_ids]
+        self.parameter_types = [Column.data_types[dtid] for dtid in parameter_type_ids]
 
 
-ParameterDescription._message_id('t')
+ParameterDescription._message_id(b't')
