@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from vertica_python.vertica.messages.message import BackendMessage
 
@@ -7,4 +7,4 @@ class PortalSuspended(BackendMessage):
     pass
 
 
-PortalSuspended._message_id('s')
+PortalSuspended._message_id(b's')
