@@ -1,6 +1,4 @@
-from __future__ import absolute_import
 
-import string
 
 from struct import unpack, unpack_from
 
@@ -15,8 +13,8 @@ class RowDescription(BackendMessage):
         field_count = unpack('!H', data[0:2])[0]
         pos = 2
 
-        for i in xrange(field_count):
-            field_info = unpack_from("!{0}sxIHIHIH".format(string.find(data, '\x00', pos) - pos), data, pos)
+        for i in range(field_count):
+            field_info = unpack_from("!{0}sxIHIHIH".format(data.find(b'\x00', pos) - pos), data, pos)
             self.fields.append({
                 'name': field_info[0],
                 'table_oid': field_info[1],
@@ -30,4 +28,4 @@ class RowDescription(BackendMessage):
             pos += 19 + len(field_info[0])
 
 
-RowDescription._message_id('T')
+RowDescription._message_id(b'T')
