@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from struct import pack
 
@@ -16,4 +16,4 @@ class CopyData(FrontendMessage):
         return self.message_string(pack('{0}s'.format(len(encoded)), encoded))
 
 
-CopyData._message_id('d')
+CopyData._message_id(b'd')
