@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 from struct import pack
 
@@ -16,11 +16,11 @@ class Startup(FrontendMessage):
     def to_bytes(self):
         startstr = pack('!I', vertica_python.PROTOCOL_VERSION)
         if self.user is not None:
-            startstr = startstr + pack('4sx{0}sx'.format(len(self.user)), 'user', self.user)
+            startstr = startstr + pack('4sx{0}sx'.format(len(self.user)), b'user', self.user)
         if self.database is not None:
-            startstr = startstr + pack('8sx{0}sx'.format(len(self.database)), 'database', self.database)
+            startstr = startstr + pack('8sx{0}sx'.format(len(self.database)), b'database', self.database)
         if self.options is not None:
-            startstr = startstr + pack('7sx{0}sx'.format(len(self.options)), 'options', self.options)
+            startstr = startstr + pack('7sx{0}sx'.format(len(self.options)), b'options', self.options)
         startstr = startstr + pack('x')
         return self.message_string(startstr)
 
