@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 import types
 
@@ -29,9 +29,9 @@ class Message(object):
 
         message_size = pack('!I', bytesize)
         if self.message_id() is not None:
-            msg_with_size = "{0}{1}{2}".format(self.message_id(), message_size, msg)
+            msg_with_size = self.message_id() + message_size + msg
         else:
-            msg_with_size = "{0}{1}".format(message_size, msg)
+            msg_with_size = message_size + msg
 
         return msg_with_size
 
@@ -40,12 +40,12 @@ class BackendMessage(Message):
     MessageIdMap = {}
 
     @classmethod
-    def factory(cls, type, data):
-        klass = cls.MessageIdMap[type]
+    def factory(cls, type_, data):
+        klass = cls.MessageIdMap[type_]
         if klass is not None:
             return klass(data)
         else:
-            return messages.Unknown(type, data)
+            return messages.Unknown(type_, data)
 
     @classmethod
     def _message_id(cls, message_id):
@@ -55,4 +55,4 @@ class BackendMessage(Message):
 
 class FrontendMessage(Message):
     def to_bytes(self):
-        return self.message_string('')
+        return self.message_string(b'')
